% function [E] = potentialenergy(K,F,u,param)
% function [E] = potentialenergy(efunc,u,param)
%
% -- Compute the total potential energy of a two variable system with 
%
%    1. Stiffness "K" and load "F" as a function of the displacements "u". 
%
%      Pi_{total} = Pi_{elastic} = Pi_{load}
%
%    where
%   
%      Pi_{elastic} = 1/2*u'*K*u
%      Pi_{load}    = -u'*F
% 
%    or    
%
%    2. Given the potential energy function "efunc".
%
%      Pi_{total} = efunc
%
%        Pi_{total} = Pi_{elastic} + Pi_{load}
%
%                   = 1/2*u^T*K*u  - u^T*F
%
%    given the displacement vector u
%
% Inputs: K              -- The stiffness matrix
%         F              -- The forcing vector
%         efunc          -- the energy of the system, where it is a function
%                           handle of the form,
% 
%                             [E] = param.efunc(u)
%
%                           where u (2-by-1 vector) and E is the energy 
%                           evaluated at u.
%         u              -- The displacement vector at which the 
%                           total potential energy is evaluated
%         param.u1_range -- a 2-by-1 array defining range of variable u1, where
%                              param.u1_range(1) :u1min
%                              param.u1_range(2) :u1max
%         param.u2_range -- a 2-by-1 array defining range of variable u2, where
%                              param.u2_range(1) :u2min
%                              param.u2_range(2) :u2max
%         param.contourplot_num
%                        -- Figure Number for the surface plot
%
% Ouptuts:E    -- The total potential energy at u
%
function [E] = potentialenergy(K,F,u,param)

if isreal(K)
    if nargin < 4, param = []; end
else
    efunc = K;
    if nargin < 3, 
        param = [];
        u     = F;
    else
        param = u;
        u     = F;
    end
end

if isreal(K)
    % -- Compute the energy for the linear mechanical system
    %
    %      E = 1/2*u^T*K*u  - u^T*F
    % 
    %    COMPLETE THIS PROCEDURE


else
    E   = efunc(u);
end

% -- Plot points
if isfield(param,'contourplot_num') & size(u,1)==2
    if ~isfield(param,'contourplot_pause'), param.contourplot_pause=0.5; end;
    figure(param.contourplot_num);
    hold on;
    plot(u(1),u(2),'r*');
    axis([param.u1_range(1),param.u1_range(2),param.u2_range(1),param.u2_range(2)]);
    hold off;
    pause(param.contourplot_pause);
end
