clear mesh;

% -- Specify the problem
mesh.ndim  = 2;       % -- Dimension of problem
mesh.ndof  = 2;       % -- Degrees of freedom per node
mesh.num_ev= 1;       % -- Number of element variables
mesh.etype = 'truss'; % -- Type of element

% -- Node to coordinate array
%
%        mesh.node  -- An array of size (ndim)-by-(number of nodes)   
%    
%    For the 2D case,
%
%        mesh.node =     [node1.x, node2.x,...]
%                        [node1.y, node2,y,...]
%
mesh.node = [0, 1, 1;
             0, 0, 1;];

% -- Element connectivity array
%
%        mesh.conn  -- An array of size 
%                      (number of connections)-by-(number of elements)   
%
%    For the 'truss' case,
%
%        mesh.conn =  [element1.n1, element2.n1,...]
%                     [element1.n2, element2.n2,...]
%
mesh.conn = [1, 2;
             3, 3;];

% -- Material properties
%
%        mesh.mat         -- An array of structures of 
%                            size (number of elements)
%
%    The material properties for 'i'th element number
%
%        mesh.mat{i}.E    -- Youngs modulus
%        mesh.mat{i}.A    -- Cross-sectional area
%
mat1.E     = 1e3;
mat1.A     = 1;
mesh.mat{1}= mat1;
mesh.mat{2}= mat1;

% -- Node to boundary condition code array
%
%        mesh.bc -- An array of size 
%                   (ndof)-by-(number of nodes)
%   
%    The entries of this array take either a value of 0 or 1.
%    For the i-th degree of freedom for the j-th node, 
%
%        mesh.bc(i,j) = 0     -- Implies Known Force        BC
%        mesh.bc(i,j) = 1     -- Implies Known Displacement BC
%
mesh.bc     = zeros(mesh.ndof,size(mesh.node,2)); 
                       % -- Initally assume all Known Force BC
mesh.bc(:,1) = [1;
                1;];
mesh.bc(:,2) = [1;
                1;];

% -- Nodal displacement value array
%
%        mesh.u -- An array of size 
%                  (ndof)-by-(number of nodes)
%    
%    The entries of this array store the value of the nodal displacements
%    The displacement in the direction of the i-th degree of freedom 
%                                     for the j-th node             
%    is  mesh.u(i,j)
%
%    One must preset the nodal displacement values for 
%    the KNOWN DISPLACEMENT BCs
%
mesh.u      = zeros(mesh.ndof,size(mesh.node,2)); 
mesh.u(:,1) = [0.0;
               0.0];
mesh.u(:,2) = [0.0;
               0.0];

% -- Nodal force value array
%
%        mesh.f -- An array of size 
%                  (ndof)-by-(number of nodes)
%    
%    The entries of this array store the value of the nodal forces 
%    The force in the direction of the i-th degree of freedom 
%                              for the j-th node             
%    is  mesh.f(i,j)
%
%    One must preset the nodal force values for 
%    the KNOWN FORCE BCs
%
mesh.f      = zeros(mesh.ndof,size(mesh.node,2)); 
mesh.f(:,3) = [1.0;
               0.0];
